@@ -26,17 +26,11 @@ GCS_BUCKET = "postgres_to_gcs_example"
 FILENAME = "test_file"
 SQL_QUERY = "select * from test_table;"
 
-default_args = {"start_date": days_ago(1)}
-
 with models.DAG(
     dag_id='example_postgres_to_gcs',
-    default_args=default_args,
-    schedule_interval=None,
+    schedule_interval=None,  # Override to match your needs
+    start_date=days_ago(1),
 ) as dag:
     upload_data = PostgresToGCSOperator(
-        task_id="get_data",
-        sql=SQL_QUERY,
-        bucket=GCS_BUCKET,
-        filename=FILENAME,
-        gzip=False
+        task_id="get_data", sql=SQL_QUERY, bucket=GCS_BUCKET, filename=FILENAME, gzip=False
     )
