@@ -15,9 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains a Google Storage Transfer Service Hook.
-"""
+"""This module contains a Google Storage Transfer Service Hook."""
 
 import json
 import logging
@@ -25,9 +23,9 @@ import time
 import warnings
 from copy import deepcopy
 from datetime import timedelta
-from typing import Dict, List, Optional, Sequence, Set, Union
+from typing import List, Optional, Sequence, Set, Union
 
-from googleapiclient.discovery import build
+from googleapiclient.discovery import build, Resource
 from googleapiclient.errors import HttpError
 
 from airflow.exceptions import AirflowException
@@ -40,9 +38,7 @@ TIME_TO_SLEEP_IN_SECONDS = 10
 
 
 class GcpTransferJobsStatus:
-    """
-    Class with Google Cloud Transfer jobs statuses.
-    """
+    """Class with Google Cloud Transfer jobs statuses."""
 
     ENABLED = "ENABLED"
     DISABLED = "DISABLED"
@@ -50,9 +46,7 @@ class GcpTransferJobsStatus:
 
 
 class GcpTransferOperationStatus:
-    """
-    Class with Google Cloud Transfer operations statuses.
-    """
+    """Class with Google Cloud Transfer operations statuses."""
 
     IN_PROGRESS = "IN_PROGRESS"
     PAUSED = "PAUSED"
@@ -143,7 +137,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         self.api_version = api_version
         self._conn = None
 
-    def get_conn(self):
+    def get_conn(self) -> Resource:
         """
         Retrieves connection to Google Storage Transfer service.
 
@@ -157,7 +151,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             )
         return self._conn
 
-    def create_transfer_job(self, body: Dict) -> Dict:
+    def create_transfer_job(self, body: dict) -> dict:
         """
         Creates a transfer job that runs periodically.
 
@@ -202,7 +196,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         return transfer_job
 
     @GoogleBaseHook.fallback_to_default_project_id
-    def get_transfer_job(self, job_name: str, project_id: str) -> Dict:
+    def get_transfer_job(self, job_name: str, project_id: str) -> dict:
         """
         Gets the latest state of a long-running operation in Google Storage
         Transfer Service.
@@ -223,7 +217,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             .execute(num_retries=self.num_retries)
         )
 
-    def list_transfer_job(self, request_filter: Optional[Dict] = None, **kwargs) -> List[Dict]:
+    def list_transfer_job(self, request_filter: Optional[dict] = None, **kwargs) -> List[dict]:
         """
         Lists long-running operations in Google Storage Transfer
         Service that match the specified filter.
@@ -239,8 +233,8 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         if request_filter is None:
             if 'filter' in kwargs:
                 request_filter = kwargs['filter']
-                if not isinstance(request_filter, Dict):
-                    raise ValueError(f"The request_filter should be Dict and is {type(request_filter)}")
+                if not isinstance(request_filter, dict):
+                    raise ValueError(f"The request_filter should be dict and is {type(request_filter)}")
                 warnings.warn("Use 'request_filter' instead of 'filter'", DeprecationWarning)
             else:
                 raise TypeError("list_transfer_job missing 1 required positional argument: 'request_filter'")
@@ -248,7 +242,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         conn = self.get_conn()
         request_filter = self._inject_project_id(request_filter, FILTER, FILTER_PROJECT_ID)
         request = conn.transferJobs().list(filter=json.dumps(request_filter))  # pylint: disable=no-member
-        jobs = []  # type: List[Dict]
+        jobs: List[dict] = []
 
         while request is not None:
             response = request.execute(num_retries=self.num_retries)
@@ -260,7 +254,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         return jobs
 
     @GoogleBaseHook.fallback_to_default_project_id
-    def enable_transfer_job(self, job_name: str, project_id: str) -> Dict:
+    def enable_transfer_job(self, job_name: str, project_id: str) -> dict:
         """
         New transfers will be performed based on the schedule.
 
@@ -287,7 +281,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             .execute(num_retries=self.num_retries)
         )
 
-    def update_transfer_job(self, job_name: str, body: Dict) -> Dict:
+    def update_transfer_job(self, job_name: str, body: dict) -> dict:
         """
         Updates a transfer job that runs periodically.
 
@@ -349,7 +343,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             num_retries=self.num_retries
         )
 
-    def get_transfer_operation(self, operation_name: str) -> Dict:
+    def get_transfer_operation(self, operation_name: str) -> dict:
         """
         Gets an transfer operation in Google Storage Transfer Service.
 
@@ -367,7 +361,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             .execute(num_retries=self.num_retries)
         )
 
-    def list_transfer_operations(self, request_filter: Optional[Dict] = None, **kwargs) -> List[Dict]:
+    def list_transfer_operations(self, request_filter: Optional[dict] = None, **kwargs) -> List[dict]:
         """
         Gets an transfer operation in Google Storage Transfer Service.
 
@@ -388,8 +382,8 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         if request_filter is None:
             if 'filter' in kwargs:
                 request_filter = kwargs['filter']
-                if not isinstance(request_filter, Dict):
-                    raise ValueError(f"The request_filter should be Dict and is {type(request_filter)}")
+                if not isinstance(request_filter, dict):
+                    raise ValueError(f"The request_filter should be dict and is {type(request_filter)}")
                 warnings.warn("Use 'request_filter' instead of 'filter'", DeprecationWarning)
             else:
                 raise TypeError(
@@ -400,7 +394,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
         request_filter = self._inject_project_id(request_filter, FILTER, FILTER_PROJECT_ID)
 
-        operations = []  # type: List[Dict]
+        operations: List[dict] = []
 
         request = conn.transferOperations().list(  # pylint: disable=no-member
             name=TRANSFER_OPERATIONS, filter=json.dumps(request_filter)
@@ -443,7 +437,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
     def wait_for_transfer_job(
         self,
-        job: Dict,
+        job: dict,
         expected_statuses: Optional[Set[str]] = None,
         timeout: Optional[Union[float, timedelta]] = None,
     ) -> None:
@@ -484,7 +478,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             time.sleep(TIME_TO_SLEEP_IN_SECONDS)
         raise AirflowException("Timeout. The operation could not be completed within the allotted time.")
 
-    def _inject_project_id(self, body: Dict, param_name: str, target_key: str) -> Dict:
+    def _inject_project_id(self, body: dict, param_name: str, target_key: str) -> dict:
         body = deepcopy(body)
         body[target_key] = body.get(target_key, self.project_id)
         if not body.get(target_key):
@@ -498,7 +492,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
     @staticmethod
     def operations_contain_expected_statuses(
-        operations: List[Dict], expected_statuses: Union[Set[str], str]
+        operations: List[dict], expected_statuses: Union[Set[str], str]
     ) -> bool:
         """
         Checks whether the operation list has an operation with the
