@@ -15,12 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains a Google Compute Engine Hook.
-"""
+"""This module contains a Google Compute Engine Hook."""
 
 import time
-from typing import Any, Dict, Optional, Sequence, Union
+from typing import Any, Optional, Sequence, Union
 
 from googleapiclient.discovery import build
 
@@ -32,9 +30,7 @@ TIME_TO_SLEEP_IN_SECONDS = 1
 
 
 class GceOperationStatus:
-    """
-    Class with GCE operations statuses.
-    """
+    """Class with GCE operations statuses."""
 
     PENDING = "PENDING"
     RUNNING = "RUNNING"
@@ -140,7 +136,7 @@ class ComputeEngineHook(GoogleBaseHook):
         self._wait_for_operation_to_complete(project_id=project_id, operation_name=operation_name, zone=zone)
 
     @GoogleBaseHook.fallback_to_default_project_id
-    def set_machine_type(self, zone: str, resource_id: str, body: Dict, project_id: str) -> None:
+    def set_machine_type(self, zone: str, resource_id: str, body: dict, project_id: str) -> None:
         """
         Sets machine type of an instance defined by project_id, zone and resource_id.
         Must be called with keyword arguments rather than positional.
@@ -168,7 +164,7 @@ class ComputeEngineHook(GoogleBaseHook):
             )
         self._wait_for_operation_to_complete(project_id=project_id, operation_name=operation_name, zone=zone)
 
-    def _execute_set_machine_type(self, zone: str, resource_id: str, body: Dict, project_id: str) -> Dict:
+    def _execute_set_machine_type(self, zone: str, resource_id: str, body: dict, project_id: str) -> dict:
         # noqa pylint: disable=no-member
         return (
             self.get_conn()
@@ -178,7 +174,7 @@ class ComputeEngineHook(GoogleBaseHook):
         )
 
     @GoogleBaseHook.fallback_to_default_project_id
-    def get_instance_template(self, resource_id: str, project_id: str) -> Dict:
+    def get_instance_template(self, resource_id: str, project_id: str) -> dict:
         """
         Retrieves instance template by project_id and resource_id.
         Must be called with keyword arguments rather than positional.
@@ -205,7 +201,7 @@ class ComputeEngineHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def insert_instance_template(
         self,
-        body: Dict,
+        body: dict,
         project_id: str,
         request_id: Optional[str] = None,
     ) -> None:
@@ -248,7 +244,7 @@ class ComputeEngineHook(GoogleBaseHook):
         zone: str,
         resource_id: str,
         project_id: str,
-    ) -> Dict:
+    ) -> dict:
         """
         Retrieves Instance Group Manager by project_id, zone and resource_id.
         Must be called with keyword arguments rather than positional.
@@ -279,7 +275,7 @@ class ComputeEngineHook(GoogleBaseHook):
         self,
         zone: str,
         resource_id: str,
-        body: Dict,
+        body: dict,
         project_id: str,
         request_id: Optional[str] = None,
     ) -> None:
@@ -366,7 +362,7 @@ class ComputeEngineHook(GoogleBaseHook):
     @staticmethod
     def _check_zone_operation_status(
         service: Any, operation_name: str, project_id: str, zone: str, num_retries: int
-    ) -> Dict:
+    ) -> dict:
         return (
             service.zoneOperations()
             .get(project=project_id, zone=zone, operation=operation_name)
@@ -376,7 +372,7 @@ class ComputeEngineHook(GoogleBaseHook):
     @staticmethod
     def _check_global_operation_status(
         service: Any, operation_name: str, project_id: str, num_retries: int
-    ) -> Dict:
+    ) -> dict:
         return (
             service.globalOperations()
             .get(project=project_id, operation=operation_name)
