@@ -15,9 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains a Google Dataflow Hook.
-"""
+"""This module contains a Google Dataflow Hook."""
 import functools
 import json
 import re
@@ -30,7 +28,7 @@ import uuid
 import warnings
 from copy import deepcopy
 from tempfile import TemporaryDirectory
-from typing import Any, Callable, Dict, List, Optional, Sequence, TypeVar, Union, cast
+from typing import Any, Callable, List, Optional, Sequence, TypeVar, Union, cast
 
 from googleapiclient.discovery import build
 
@@ -96,22 +94,36 @@ _fallback_to_project_id_from_variables = _fallback_variable_parameter('project_i
 class DataflowJobStatus:
     """
     Helper class with Dataflow job statuses.
+    Reference: https://cloud.google.com/dataflow/docs/reference/rest/v1b3/projects.jobs#Job.JobState
     """
 
     JOB_STATE_DONE = "JOB_STATE_DONE"
+    JOB_STATE_UNKNOWN = "JOB_STATE_UNKNOWN"
+    JOB_STATE_STOPPED = "JOB_STATE_STOPPED"
     JOB_STATE_RUNNING = "JOB_STATE_RUNNING"
     JOB_STATE_FAILED = "JOB_STATE_FAILED"
     JOB_STATE_CANCELLED = "JOB_STATE_CANCELLED"
+    JOB_STATE_UPDATED = "JOB_STATE_UPDATED"
+    JOB_STATE_DRAINING = "JOB_STATE_DRAINING"
+    JOB_STATE_DRAINED = "JOB_STATE_DRAINED"
     JOB_STATE_PENDING = "JOB_STATE_PENDING"
+    JOB_STATE_CANCELLING = "JOB_STATE_CANCELLING"
+    JOB_STATE_QUEUED = "JOB_STATE_QUEUED"
     FAILED_END_STATES = {JOB_STATE_FAILED, JOB_STATE_CANCELLED}
-    SUCCEEDED_END_STATES = {JOB_STATE_DONE}
-    END_STATES = SUCCEEDED_END_STATES | FAILED_END_STATES
+    SUCCEEDED_END_STATES = {JOB_STATE_DONE, JOB_STATE_UPDATED, JOB_STATE_DRAINED}
+    TERMINAL_STATES = SUCCEEDED_END_STATES | FAILED_END_STATES
+    AWAITING_STATES = {
+        JOB_STATE_RUNNING,
+        JOB_STATE_PENDING,
+        JOB_STATE_QUEUED,
+        JOB_STATE_CANCELLING,
+        JOB_STATE_DRAINING,
+        JOB_STATE_STOPPED,
+    }
 
 
 class DataflowJobType:
-    """
-    Helper class with Dataflow job types.
-    """
+    """Helper class with Dataflow job types."""
 
     JOB_TYPE_UNKNOWN = "JOB_TYPE_UNKNOWN"
     JOB_TYPE_BATCH = "JOB_TYPE_BATCH"
@@ -156,7 +168,7 @@ class _DataflowJobsController(LoggingMixin):
         self._job_id = job_id
         self._num_retries = num_retries
         self._poll_sleep = poll_sleep
-        self._jobs = None  # type: Optional[List[Dict]]
+        self._jobs: Optional[List[dict]] = None
 
     def is_job_running(self) -> bool:
         """
@@ -170,12 +182,12 @@ class _DataflowJobsController(LoggingMixin):
             return False
 
         for job in self._jobs:
-            if job['currentState'] not in DataflowJobStatus.END_STATES:
+            if job['currentState'] not in DataflowJobStatus.TERMINAL_STATES:
                 return True
         return False
 
     # pylint: disable=too-many-nested-blocks
-    def _get_current_jobs(self) -> List[Dict]:
+    def _get_current_jobs(self) -> List[dict]:
         """
         Helper method to get list of jobs that start with job name or id
 
@@ -192,7 +204,7 @@ class _DataflowJobsController(LoggingMixin):
         else:
             raise Exception('Missing both dataflow job ID and name.')
 
-    def _fetch_job_by_id(self, job_id: str) -> Dict:
+    def _fetch_job_by_id(self, job_id: str) -> dict:
         return (
             self._dataflow.projects()
             .locations()
@@ -201,14 +213,14 @@ class _DataflowJobsController(LoggingMixin):
             .execute(num_retries=self._num_retries)
         )
 
-    def _fetch_all_jobs(self) -> List[Dict]:
+    def _fetch_all_jobs(self) -> List[dict]:
         request = (
             self._dataflow.projects()
             .locations()
             .jobs()
             .list(projectId=self._project_number, location=self._job_location)
         )
-        jobs = []  # type: List[Dict]
+        jobs: List[dict] = []
         while request is not None:
             response = request.execute(num_retries=self._num_retries)
             jobs.extend(response["jobs"])
@@ -221,7 +233,7 @@ class _DataflowJobsController(LoggingMixin):
             )
         return jobs
 
-    def _fetch_jobs_by_prefix_name(self, prefix_name: str) -> List[Dict]:
+    def _fetch_jobs_by_prefix_name(self, prefix_name: str) -> List[dict]:
         jobs = self._fetch_all_jobs()
         jobs = [job for job in jobs if job['name'].startswith(prefix_name)]
         return jobs
@@ -261,10 +273,7 @@ class _DataflowJobsController(LoggingMixin):
             and DataflowJobType.JOB_TYPE_STREAMING == job['type']
         ):
             return True
-        elif job['currentState'] in {
-            DataflowJobStatus.JOB_STATE_RUNNING,
-            DataflowJobStatus.JOB_STATE_PENDING,
-        }:
+        elif job['currentState'] in DataflowJobStatus.AWAITING_STATES:
             return False
         self.log.debug("Current job: %s", str(job))
         raise Exception(
@@ -272,9 +281,7 @@ class _DataflowJobsController(LoggingMixin):
         )
 
     def wait_for_done(self) -> None:
-        """
-        Helper method to wait for result of submitted job.
-        """
+        """Helper method to wait for result of submitted job."""
         self.log.info("Start waiting for done.")
         self._refresh_jobs()
         while self._jobs and not all(self._check_dataflow_job_state(job) for job in self._jobs):
@@ -282,14 +289,14 @@ class _DataflowJobsController(LoggingMixin):
             time.sleep(self._poll_sleep)
             self._refresh_jobs()
 
-    def get_jobs(self) -> List[Dict]:
+    def get_jobs(self, refresh=False) -> List[dict]:
         """
         Returns Dataflow jobs.
 
         :return: list of jobs
         :rtype: list
         """
-        if not self._jobs:
+        if not self._jobs or refresh:
             self._refresh_jobs()
         if not self._jobs:
             raise ValueError("Could not read _jobs")
@@ -297,26 +304,27 @@ class _DataflowJobsController(LoggingMixin):
         return self._jobs
 
     def cancel(self) -> None:
-        """
-        Cancels current job
-        """
-        jobs = self._get_current_jobs()
-        batch = self._dataflow.new_batch_http_request()
-        job_ids = [job['id'] for job in jobs]
-        self.log.info("Canceling jobs: %s", ", ".join(job_ids))
-        for job_id in job_ids:
-            batch.add(
-                self._dataflow.projects()
-                .locations()
-                .jobs()
-                .update(
-                    projectId=self._project_number,
-                    location=self._job_location,
-                    jobId=job_id,
-                    body={"requestedState": DataflowJobStatus.JOB_STATE_CANCELLED},
+        """Cancels current job"""
+        jobs = self.get_jobs()
+        job_ids = [job['id'] for job in jobs if job['currentState'] not in DataflowJobStatus.TERMINAL_STATES]
+        if job_ids:
+            batch = self._dataflow.new_batch_http_request()
+            self.log.info("Canceling jobs: %s", ", ".join(job_ids))
+            for job_id in job_ids:
+                batch.add(
+                    self._dataflow.projects()
+                    .locations()
+                    .jobs()
+                    .update(
+                        projectId=self._project_number,
+                        location=self._job_location,
+                        jobId=job_id,
+                        body={"requestedState": DataflowJobStatus.JOB_STATE_CANCELLED},
+                    )
                 )
-            )
-        batch.execute()
+            batch.execute()
+        else:
+            self.log.info("No jobs to cancel")
 
 
 class _DataflowRunner(LoggingMixin):
@@ -427,20 +435,18 @@ class DataflowHook(GoogleBaseHook):
             impersonation_chain=impersonation_chain,
         )
 
-    def get_conn(self):
-        """
-        Returns a Google Cloud Dataflow service object.
-        """
+    def get_conn(self) -> build:
+        """Returns a Google Cloud Dataflow service object."""
         http_authorized = self._authorize()
         return build('dataflow', 'v1b3', http=http_authorized, cache_discovery=False)
 
     @GoogleBaseHook.provide_gcp_credential_file
     def _start_dataflow(
         self,
-        variables: Dict,
+        variables: dict,
         name: str,
         command_prefix: List[str],
-        label_formatter: Callable[[Dict], List[str]],
+        label_formatter: Callable[[dict], List[str]],
         project_id: str,
         multiple_jobs: bool = False,
         on_new_job_id_callback: Optional[Callable[[str], None]] = None,
@@ -467,7 +473,7 @@ class DataflowHook(GoogleBaseHook):
     def start_java_dataflow(
         self,
         job_name: str,
-        variables: Dict,
+        variables: dict,
         jar: str,
         project_id: str,
         job_class: Optional[str] = None,
@@ -523,20 +529,22 @@ class DataflowHook(GoogleBaseHook):
     def start_template_dataflow(
         self,
         job_name: str,
-        variables: Dict,
-        parameters: Dict,
+        variables: dict,
+        parameters: dict,
         dataflow_template: str,
         project_id: str,
         append_job_name: bool = True,
         on_new_job_id_callback: Optional[Callable[[str], None]] = None,
         location: str = DEFAULT_DATAFLOW_LOCATION,
-    ) -> Dict:
+        environment: Optional[dict] = None,
+    ) -> dict:
         """
         Starts Dataflow template job.
 
         :param job_name: The name of the job.
         :type job_name: str
         :param variables: Map of job runtime environment options.
+            It will update environment argument if passed.
 
             .. seealso::
                 For more information on possible configurations, look at the API documentation
@@ -556,9 +564,48 @@ class DataflowHook(GoogleBaseHook):
         :type on_new_job_id_callback: callable
         :param location: Job location.
         :type location: str
+        :type environment: Optional, Map of job runtime environment options.
+
+            .. seealso::
+                For more information on possible configurations, look at the API documentation
+                `https://cloud.google.com/dataflow/pipelines/specifying-exec-params
+                <https://cloud.google.com/dataflow/docs/reference/rest/v1b3/RuntimeEnvironment>`__
+
+        :type environment: Optional[dict]
         """
         name = self._build_dataflow_job_name(job_name, append_job_name)
 
+        environment = environment or {}
+        # available keys for runtime environment are listed here:
+        # https://cloud.google.com/dataflow/docs/reference/rest/v1b3/RuntimeEnvironment
+        environment_keys = [
+            'numWorkers',
+            'maxWorkers',
+            'zone',
+            'serviceAccountEmail',
+            'tempLocation',
+            'bypassTempDirValidation',
+            'machineType',
+            'additionalExperiments',
+            'network',
+            'subnetwork',
+            'additionalUserLabels',
+            'kmsKeyName',
+            'ipConfiguration',
+            'workerRegion',
+            'workerZone',
+        ]
+
+        for key in variables:
+            if key in environment_keys:
+                if key in environment:
+                    self.log.warning(
+                        "'%s' parameter in 'variables' will override of "
+                        "the same one passed in 'environment'!",
+                        key,
+                    )
+                environment.update({key: variables[key]})
+
         service = self.get_conn()
         # pylint: disable=no-member
         request = (
@@ -569,7 +616,7 @@ class DataflowHook(GoogleBaseHook):
                 projectId=project_id,
                 location=location,
                 gcsPath=dataflow_template,
-                body={"jobName": name, "parameters": parameters, "environment": variables},
+                body={"jobName": name, "parameters": parameters, "environment": environment},
             )
         )
         response = request.execute(num_retries=self.num_retries)
@@ -590,13 +637,59 @@ class DataflowHook(GoogleBaseHook):
         jobs_controller.wait_for_done()
         return response["job"]
 
+    @GoogleBaseHook.fallback_to_default_project_id
+    def start_flex_template(
+        self,
+        body: dict,
+        location: str,
+        project_id: str,
+        on_new_job_id_callback: Optional[Callable[[str], None]] = None,
+    ):
+        """
+        Starts flex templates with the Dataflow  pipeline.
+
+        :param body: The request body. See:
+            https://cloud.google.com/dataflow/docs/reference/rest/v1b3/projects.locations.flexTemplates/launch#request-body
+        :param location: The location of the Dataflow job (for example europe-west1)
+        :type location: str
+        :param project_id: The ID of the GCP project that owns the job.
+            If set to ``None`` or missing, the default project_id from the GCP connection is used.
+        :type project_id: Optional[str]
+        :param on_new_job_id_callback: A callback that is called when a Job ID is detected.
+        :return: the Job
+        """
+        service = self.get_conn()
+        request = (
+            service.projects()  # pylint: disable=no-member
+            .locations()
+            .flexTemplates()
+            .launch(projectId=project_id, body=body, location=location)
+        )
+        response = request.execute(num_retries=self.num_retries)
+        job_id = response['job']['id']
+
+        if on_new_job_id_callback:
+            on_new_job_id_callback(job_id)
+
+        jobs_controller = _DataflowJobsController(
+            dataflow=self.get_conn(),
+            project_number=project_id,
+            job_id=job_id,
+            location=location,
+            poll_sleep=self.poll_sleep,
+            num_retries=self.num_retries,
+        )
+        jobs_controller.wait_for_done()
+
+        return jobs_controller.get_jobs(refresh=True)[0]
+
     @_fallback_to_location_from_variables
     @_fallback_to_project_id_from_variables
     @GoogleBaseHook.fallback_to_default_project_id
     def start_python_dataflow(  # pylint: disable=too-many-arguments
         self,
         job_name: str,
-        variables: Dict,
+        variables: dict,
         dataflow: str,
         py_options: List[str],
         project_id: str,
@@ -618,6 +711,9 @@ class DataflowHook(GoogleBaseHook):
         :type dataflow: str
         :param py_options: Additional options.
         :type py_options: List[str]
+        :param project_id: The ID of the GCP project that owns the job.
+            If set to ``None`` or missing, the default project_id from the GCP connection is used.
+        :type project_id: Optional[str]
         :param py_interpreter: Python version of the beam pipeline.
             If None, this defaults to the python3.
             To track python versions supported by beam and related
@@ -714,7 +810,7 @@ class DataflowHook(GoogleBaseHook):
         return safe_job_name
 
     @staticmethod
-    def _build_cmd(variables: Dict, label_formatter: Callable, project_id: str) -> List[str]:
+    def _build_cmd(variables: dict, label_formatter: Callable, project_id: str) -> List[str]:
         command = [
             "--runner=DataflowRunner",
             "--project={}".format(project_id),
@@ -746,7 +842,7 @@ class DataflowHook(GoogleBaseHook):
         name: str,
         project_id: str,
         location: str = DEFAULT_DATAFLOW_LOCATION,
-        variables: Optional[Dict] = None,
+        variables: Optional[dict] = None,
     ) -> bool:
         """
         Helper method to check if jos is still running in dataflow
