@@ -18,7 +18,7 @@
 
 """
 This module contains a CloudDLPHook
-which allows you to connect to GCP Cloud DLP service.
+which allows you to connect to Google Cloud DLP service.
 """
 
 import re
@@ -28,10 +28,25 @@ from typing import List, Optional, Sequence, Tuple, Union
 from google.api_core.retry import Retry
 from google.cloud.dlp_v2 import DlpServiceClient
 from google.cloud.dlp_v2.types import (
-    ByteContentItem, ContentItem, DeidentifyConfig, DeidentifyContentResponse, DeidentifyTemplate, DlpJob,
-    FieldMask, InspectConfig, InspectContentResponse, InspectJobConfig, InspectTemplate, JobTrigger,
-    ListInfoTypesResponse, RedactImageRequest, RedactImageResponse, ReidentifyContentResponse,
-    RiskAnalysisJobConfig, StoredInfoType, StoredInfoTypeConfig,
+    ByteContentItem,
+    ContentItem,
+    DeidentifyConfig,
+    DeidentifyContentResponse,
+    DeidentifyTemplate,
+    DlpJob,
+    FieldMask,
+    InspectConfig,
+    InspectContentResponse,
+    InspectJobConfig,
+    InspectTemplate,
+    JobTrigger,
+    ListInfoTypesResponse,
+    RedactImageRequest,
+    RedactImageResponse,
+    ReidentifyContentResponse,
+    RiskAnalysisJobConfig,
+    StoredInfoType,
+    StoredInfoTypeConfig,
 )
 
 from airflow.exceptions import AirflowException
@@ -48,25 +63,43 @@ class CloudDLPHook(GoogleBaseHook):
     Information (PII) and other privacy-sensitive data in user-supplied,
     unstructured data streams, like text blocks or images. The service also
     includes methods for sensitive data redaction and scheduling of data scans
-    on Google Cloud Platform based data sets.
+    on Google Cloud based data sets.
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
     :type gcp_conn_id: str
-    :param delegate_to: The account to impersonate, if any.
-        For this to work, the service account making the request must have
+    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
+        if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
     :type delegate_to: str
+    :param impersonation_chain: Optional service account to impersonate using short-term
+        credentials, or chained list of accounts required to get the access_token
+        of the last account in the list, which will be impersonated in the request.
+        If set as a string, the account must grant the originating account
+        the Service Account Token Creator IAM role.
+        If set as a sequence, the identities from the list must grant
+        Service Account Token Creator IAM role to the directly preceding identity, with first
+        account from the list granting this role to the originating account.
+    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    def __init__(self, gcp_conn_id: str = "google_cloud_default", delegate_to: Optional[str] = None) -> None:
-        super().__init__(gcp_conn_id, delegate_to)
+    def __init__(
+        self,
+        gcp_conn_id: str = "google_cloud_default",
+        delegate_to: Optional[str] = None,
+        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+    ) -> None:
+        super().__init__(
+            gcp_conn_id=gcp_conn_id,
+            delegate_to=delegate_to,
+            impersonation_chain=impersonation_chain,
+        )
         self._client = None
 
     def get_conn(self) -> DlpServiceClient:
         """
         Provides a client for interacting with the Cloud DLP API.
 
-        :return: GCP Cloud DLP API Client
+        :return: Google Cloud DLP API Client
         :rtype: google.cloud.dlp_v2.DlpServiceClient
         """
         if not self._client:
@@ -87,9 +120,9 @@ class CloudDLPHook(GoogleBaseHook):
 
         :param dlp_job_id: ID of the DLP job resource to be cancelled.
         :type dlp_job_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default project_id
-            from the GCP connection is used.
+            from the Google Cloud connection is used.
         :type project_id: str
         :param retry: (Optional) A retry object used to retry requests.
             If None is specified, requests will not be retried.
@@ -101,7 +134,6 @@ class CloudDLPHook(GoogleBaseHook):
         :param metadata: (Optional) Additional metadata that is provided to the method.
         :type metadata: Sequence[Tuple[str, str]]
         """
-
         client = self.get_conn()
 
         if not dlp_job_id:
@@ -125,13 +157,13 @@ class CloudDLPHook(GoogleBaseHook):
         de-identifying content, images, and storage.
 
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
-        :param deidentify_template: (Optional) The deidentify template to create.
+        :param deidentify_template: (Optional) The de-identify template to create.
         :type deidentify_template: dict or google.cloud.dlp_v2.types.DeidentifyTemplate
         :param template_id: (Optional) The template ID.
         :type template_id: str
@@ -146,7 +178,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.DeidentifyTemplate
         """
-
         client = self.get_conn()
         # Handle project_id from connection configuration
         project_id = project_id or self.project_id
@@ -178,14 +209,14 @@ class CloudDLPHook(GoogleBaseHook):
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
         wait_until_finished: bool = True,
-        time_to_sleep_in_seconds: int = 60
+        time_to_sleep_in_seconds: int = 60,
     ) -> DlpJob:
         """
         Creates a new job to inspect storage or calculate risk metrics.
 
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param inspect_job: (Optional) The configuration for the inspect job.
         :type inspect_job: dict or google.cloud.dlp_v2.types.InspectJobConfig
@@ -210,7 +241,6 @@ class CloudDLPHook(GoogleBaseHook):
             of the operation results. Defaults to 60.
         :type time_to_sleep_in_seconds: int
         """
-
         client = self.get_conn()
 
         parent = DlpServiceClient.project_path(project_id)
@@ -268,11 +298,11 @@ class CloudDLPHook(GoogleBaseHook):
         inspecting content, images, and storage.
 
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param inspect_template: (Optional) The inspect template to create.
         :type inspect_template: dict or google.cloud.dlp_v2.types.InspectTemplate
@@ -289,7 +319,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.InspectTemplate
         """
-
         client = self.get_conn()
 
         # Handle project_id from connection configuration
@@ -325,9 +354,9 @@ class CloudDLPHook(GoogleBaseHook):
         Creates a job trigger to run DLP actions such as scanning storage for sensitive
         information on a set schedule.
 
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param job_trigger: (Optional) The job trigger to create.
         :type job_trigger: dict or google.cloud.dlp_v2.types.JobTrigger
@@ -344,7 +373,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.JobTrigger
         """
-
         client = self.get_conn()
 
         parent = DlpServiceClient.project_path(project_id)
@@ -371,11 +399,11 @@ class CloudDLPHook(GoogleBaseHook):
         Creates a pre-built stored info type to be used for inspection.
 
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param config: (Optional) The config for the stored info type.
         :type config: dict or google.cloud.dlp_v2.types.StoredInfoTypeConfig
@@ -392,7 +420,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.StoredInfoType
         """
-
         client = self.get_conn()
 
         # Handle project_id from connection configuration
@@ -431,9 +458,9 @@ class CloudDLPHook(GoogleBaseHook):
         De-identifies potentially sensitive info from a content item. This method has limits
         on input size and output size.
 
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param deidentify_config: (Optional) Configuration for the de-identification of the
             content item. Items specified here will override the template referenced by the
@@ -462,7 +489,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.DeidentifyContentResponse
         """
-
         client = self.get_conn()
 
         parent = DlpServiceClient.project_path(project_id)
@@ -487,11 +513,11 @@ class CloudDLPHook(GoogleBaseHook):
         :param template_id: The ID of deidentify template to be deleted.
         :type template_id: str
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param retry: (Optional) A retry object used to retry requests.
             If None is specified, requests will not be retried.
@@ -503,7 +529,6 @@ class CloudDLPHook(GoogleBaseHook):
         :param metadata: (Optional) Additional metadata that is provided to the method.
         :type metadata: Sequence[Tuple[str, str]]
         """
-
         client = self.get_conn()
 
         if not template_id:
@@ -536,9 +561,9 @@ class CloudDLPHook(GoogleBaseHook):
 
         :param dlp_job_id: The ID of the DLP job resource to be cancelled.
         :type dlp_job_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param retry: (Optional) A retry object used to retry requests.
             If None is specified, requests will not be retried.
@@ -550,7 +575,6 @@ class CloudDLPHook(GoogleBaseHook):
         :param metadata: (Optional) Additional metadata that is provided to the method.
         :type metadata: Sequence[Tuple[str, str]]
         """
-
         client = self.get_conn()
 
         if not dlp_job_id:
@@ -574,11 +598,11 @@ class CloudDLPHook(GoogleBaseHook):
         :param template_id: The ID of the inspect template to be deleted.
         :type template_id: str
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param retry: (Optional) A retry object used to retry requests.
             If None is specified, requests will not be retried.
@@ -590,7 +614,6 @@ class CloudDLPHook(GoogleBaseHook):
         :param metadata: (Optional) Additional metadata that is provided to the method.
         :type metadata: Sequence[Tuple[str, str]]
         """
-
         client = self.get_conn()
 
         if not template_id:
@@ -622,9 +645,9 @@ class CloudDLPHook(GoogleBaseHook):
 
         :param job_trigger_id: The ID of the DLP job trigger to be deleted.
         :type job_trigger_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param retry: (Optional) A retry object used to retry requests.
             If None is specified, requests will not be retried.
@@ -636,7 +659,6 @@ class CloudDLPHook(GoogleBaseHook):
         :param metadata: (Optional) Additional metadata that is provided to the method.
         :type metadata: Sequence[Tuple[str, str]]
         """
-
         client = self.get_conn()
 
         if not job_trigger_id:
@@ -660,11 +682,11 @@ class CloudDLPHook(GoogleBaseHook):
         :param stored_info_type_id: The ID of the stored info type to be deleted.
         :type stored_info_type_id: str
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param retry: (Optional) A retry object used to retry requests.
             If None is specified, requests will not be retried.
@@ -676,7 +698,6 @@ class CloudDLPHook(GoogleBaseHook):
         :param metadata: (Optional) Additional metadata that is provided to the method.
         :type metadata: Sequence[Tuple[str, str]]
         """
-
         client = self.get_conn()
 
         if not stored_info_type_id:
@@ -709,11 +730,11 @@ class CloudDLPHook(GoogleBaseHook):
         :param template_id: The ID of deidentify template to be read.
         :type template_id: str
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param retry: (Optional) A retry object used to retry requests.
             If None is specified, requests will not be retried.
@@ -726,7 +747,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.DeidentifyTemplate
         """
-
         client = self.get_conn()
 
         if not template_id:
@@ -758,9 +778,9 @@ class CloudDLPHook(GoogleBaseHook):
 
         :param dlp_job_id: The ID of the DLP job resource to be read.
         :type dlp_job_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param retry: (Optional) A retry object used to retry requests.
             If None is specified, requests will not be retried.
@@ -773,7 +793,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.DlpJob
         """
-
         client = self.get_conn()
 
         if not dlp_job_id:
@@ -797,11 +816,11 @@ class CloudDLPHook(GoogleBaseHook):
         :param template_id: The ID of inspect template to be read.
         :type template_id: str
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param retry: (Optional) A retry object used to retry requests.
             If None is specified, requests will not be retried.
@@ -814,7 +833,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.InspectTemplate
         """
-
         client = self.get_conn()
 
         if not template_id:
@@ -846,9 +864,9 @@ class CloudDLPHook(GoogleBaseHook):
 
         :param job_trigger_id: The ID of the DLP job trigger to be read.
         :type job_trigger_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param retry: (Optional) A retry object used to retry requests.
             If None is specified, requests will not be retried.
@@ -861,7 +879,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.JobTrigger
         """
-
         client = self.get_conn()
 
         if not job_trigger_id:
@@ -885,11 +902,11 @@ class CloudDLPHook(GoogleBaseHook):
         :param stored_info_type_id: The ID of the stored info type to be read.
         :type stored_info_type_id: str
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param retry: (Optional) A retry object used to retry requests.
             If None is specified, requests will not be retried.
@@ -902,7 +919,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.StoredInfoType
         """
-
         client = self.get_conn()
 
         if not stored_info_type_id:
@@ -935,9 +951,9 @@ class CloudDLPHook(GoogleBaseHook):
         Finds potentially sensitive info in content. This method has limits on input size,
         processing time, and output size.
 
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param inspect_config: (Optional) Configuration for the inspector. Items specified
             here will override the template referenced by the inspect_template_name argument.
@@ -958,7 +974,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.InspectContentResponse
         """
-
         client = self.get_conn()
 
         parent = DlpServiceClient.project_path(project_id)
@@ -986,11 +1001,11 @@ class CloudDLPHook(GoogleBaseHook):
         Lists deidentify templates.
 
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param page_size: (Optional) The maximum number of resources contained in the
             underlying API response.
@@ -1009,7 +1024,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: List[google.cloud.dlp_v2.types.DeidentifyTemplate]
         """
-
         client = self.get_conn()
 
         # Handle project_id from connection configuration
@@ -1048,9 +1062,9 @@ class CloudDLPHook(GoogleBaseHook):
         """
         Lists DLP jobs that match the specified filter in the request.
 
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param results_filter: (Optional) Filter used to specify a subset of results.
         :type results_filter: str
@@ -1073,7 +1087,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: List[google.cloud.dlp_v2.types.DlpJob]
         """
-
         client = self.get_conn()
 
         parent = DlpServiceClient.project_path(project_id)
@@ -1117,7 +1130,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.ListInfoTypesResponse
         """
-
         client = self.get_conn()
 
         return client.list_info_types(
@@ -1142,11 +1154,11 @@ class CloudDLPHook(GoogleBaseHook):
         Lists inspect templates.
 
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param page_size: (Optional) The maximum number of resources contained in the
             underlying API response.
@@ -1165,7 +1177,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: List[google.cloud.dlp_v2.types.InspectTemplate]
         """
-
         client = self.get_conn()
 
         # Handle project_id from connection configuration
@@ -1202,9 +1213,9 @@ class CloudDLPHook(GoogleBaseHook):
         """
         Lists job triggers.
 
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param page_size: (Optional) The maximum number of resources contained in the
             underlying API response.
@@ -1225,7 +1236,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: List[google.cloud.dlp_v2.types.JobTrigger]
         """
-
         client = self.get_conn()
 
         parent = DlpServiceClient.project_path(project_id)
@@ -1254,11 +1264,11 @@ class CloudDLPHook(GoogleBaseHook):
         Lists stored info types.
 
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param page_size: (Optional) The maximum number of resources contained in the
             underlying API response.
@@ -1277,7 +1287,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: List[google.cloud.dlp_v2.types.StoredInfoType]
         """
-
         client = self.get_conn()
 
         # Handle project_id from connection configuration
@@ -1318,9 +1327,9 @@ class CloudDLPHook(GoogleBaseHook):
         Redacts potentially sensitive info from an image. This method has limits on
         input size, processing time, and output size.
 
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param inspect_config: (Optional) Configuration for the inspector. Items specified
             here will override the template referenced by the inspect_template_name argument.
@@ -1345,7 +1354,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.RedactImageResponse
         """
-
         client = self.get_conn()
 
         parent = DlpServiceClient.project_path(project_id)
@@ -1376,9 +1384,9 @@ class CloudDLPHook(GoogleBaseHook):
         """
         Re-identifies content that has been de-identified.
 
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param reidentify_config: (Optional) Configuration for the re-identification of
             the content item.
@@ -1405,7 +1413,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.ReidentifyContentResponse
         """
-
         client = self.get_conn()
 
         parent = DlpServiceClient.project_path(project_id)
@@ -1438,11 +1445,11 @@ class CloudDLPHook(GoogleBaseHook):
         :param template_id: The ID of deidentify template to be updated.
         :type template_id: str
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param deidentify_template: New deidentify template value.
         :type deidentify_template: dict or google.cloud.dlp_v2.types.DeidentifyTemplate
@@ -1459,7 +1466,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.DeidentifyTemplate
         """
-
         client = self.get_conn()
 
         if not template_id:
@@ -1501,11 +1507,11 @@ class CloudDLPHook(GoogleBaseHook):
         :param template_id: The ID of the inspect template to be updated.
         :type template_id: str
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param inspect_template: New inspect template value.
         :type inspect_template: dict or google.cloud.dlp_v2.types.InspectTemplate
@@ -1522,7 +1528,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.InspectTemplate
         """
-
         client = self.get_conn()
 
         if not template_id:
@@ -1562,9 +1567,9 @@ class CloudDLPHook(GoogleBaseHook):
 
         :param job_trigger_id: The ID of the DLP job trigger to be updated.
         :type job_trigger_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. If set to None or missing, the default
-            project_id from the GCP connection is used.
+            project_id from the Google Cloud connection is used.
         :type project_id: str
         :param job_trigger: New job trigger value.
         :type job_trigger: dict or google.cloud.dlp_v2.types.JobTrigger
@@ -1581,7 +1586,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.JobTrigger
         """
-
         client = self.get_conn()
 
         if not job_trigger_id:
@@ -1614,11 +1618,11 @@ class CloudDLPHook(GoogleBaseHook):
         :param stored_info_type_id: The ID of the stored info type to be updated.
         :type stored_info_type_id: str
         :param organization_id: (Optional) The organization ID. Required to set this
-            field if parent resource is an organzation.
+            field if parent resource is an organization.
         :type organization_id: str
-        :param project_id: (Optional) Google Cloud Platform project ID where the
+        :param project_id: (Optional) Google Cloud project ID where the
             DLP Instance exists. Only set this field if the parent resource is
-            a project instead of an organzation.
+            a project instead of an organization.
         :type project_id: str
         :param config: Updated configuration for the stored info type. If not provided, a new
             version of the stored info type will be created with the existing configuration.
@@ -1636,7 +1640,6 @@ class CloudDLPHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         :rtype: google.cloud.dlp_v2.types.StoredInfoType
         """
-
         client = self.get_conn()
 
         if not stored_info_type_id:
