@@ -16,9 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 #
-"""
-This module contains a Google Kubernetes Engine Hook.
-"""
+"""This module contains a Google Kubernetes Engine Hook."""
 
 import time
 import warnings
