@@ -15,9 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains a Google Cloud Spanner Hook.
-"""
+"""This module contains a Google Cloud Spanner Hook."""
 from typing import Callable, List, Optional, Sequence, Union
 
 from google.api_core.exceptions import AlreadyExists, GoogleAPICallError
