@@ -15,9 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains Google Compute Engine operators.
-"""
+"""This module contains Google Compute Engine operators."""
 
 from copy import deepcopy
 from typing import Any, Dict, List, Optional, Sequence, Union
@@ -34,9 +32,7 @@ from airflow.utils.decorators import apply_defaults
 
 
 class ComputeEngineBaseOperator(BaseOperator):
-    """
-    Abstract base operator for Google Compute Engine operators to inherit from.
-    """
+    """Abstract base operator for Google Compute Engine operators to inherit from."""
 
     @apply_defaults
     def __init__(
@@ -59,7 +55,7 @@ class ComputeEngineBaseOperator(BaseOperator):
         self._validate_inputs()
         super().__init__(**kwargs)
 
-    def _validate_inputs(self):
+    def _validate_inputs(self) -> None:
         if self.project_id == '':
             raise AirflowException("The required parameter 'project_id' is missing")
         if not self.zone:
@@ -139,7 +135,7 @@ class ComputeEngineStartInstanceOperator(ComputeEngineBaseOperator):
             **kwargs,
         )
 
-    def execute(self, context):
+    def execute(self, context) -> None:
         hook = ComputeEngineHook(
             gcp_conn_id=self.gcp_conn_id,
             api_version=self.api_version,
@@ -216,7 +212,7 @@ class ComputeEngineStopInstanceOperator(ComputeEngineBaseOperator):
             **kwargs,
         )
 
-    def execute(self, context):
+    def execute(self, context) -> None:
         hook = ComputeEngineHook(
             gcp_conn_id=self.gcp_conn_id,
             api_version=self.api_version,
@@ -312,11 +308,11 @@ class ComputeEngineSetMachineTypeOperator(ComputeEngineBaseOperator):
             **kwargs,
         )
 
-    def _validate_all_body_fields(self):
+    def _validate_all_body_fields(self) -> None:
         if self._field_validator:
             self._field_validator.validate(self.body)
 
-    def execute(self, context):
+    def execute(self, context) -> None:
         hook = ComputeEngineHook(
             gcp_conn_id=self.gcp_conn_id,
             api_version=self.api_version,
@@ -482,11 +478,11 @@ class ComputeEngineCopyInstanceTemplateOperator(ComputeEngineBaseOperator):
             **kwargs,
         )
 
-    def _validate_all_body_fields(self):
+    def _validate_all_body_fields(self) -> None:
         if self._field_validator:
             self._field_validator.validate(self.body_patch)
 
-    def execute(self, context):
+    def execute(self, context) -> dict:
         hook = ComputeEngineHook(
             gcp_conn_id=self.gcp_conn_id,
             api_version=self.api_version,
@@ -623,12 +619,12 @@ class ComputeEngineInstanceGroupUpdateManagerTemplateOperator(ComputeEngineBaseO
             **kwargs,
         )
 
-    def _possibly_replace_template(self, dictionary: Dict) -> None:
+    def _possibly_replace_template(self, dictionary: dict) -> None:
         if dictionary.get('instanceTemplate') == self.source_template:
             dictionary['instanceTemplate'] = self.destination_template
             self._change_performed = True
 
-    def execute(self, context):
+    def execute(self, context) -> Optional[bool]:
         hook = ComputeEngineHook(
             gcp_conn_id=self.gcp_conn_id,
             api_version=self.api_version,
