@@ -15,9 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains Google BigQuery to BigQuery operator.
-"""
+"""This module contains Google BigQuery to BigQuery operator."""
 import warnings
 from typing import Dict, List, Optional, Sequence, Union
 
@@ -127,7 +125,7 @@ class BigQueryToBigQueryOperator(BaseOperator):
         self.location = location
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context):
+    def execute(self, context) -> None:
         self.log.info(
             'Executing copy of %s into: %s',
             self.source_project_dataset_tables,
