@@ -22,7 +22,7 @@ from typing import Iterable, Optional, Sequence, Union
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
 from airflow.providers.amazon.aws.operators.s3_list import S3ListOperator
-from airflow.providers.google.cloud.hooks.gcs import GCSHook, _parse_gcs_url
+from airflow.providers.google.cloud.hooks.gcs import GCSHook, _parse_gcs_url, gcs_object_is_directory
 from airflow.utils.decorators import apply_defaults
 
 
@@ -145,7 +145,7 @@ class S3ToGCSOperator(S3ListOperator):
         self.gzip = gzip
         self.google_impersonation_chain = google_impersonation_chain
 
-        if dest_gcs and not self._gcs_object_is_directory(self.dest_gcs):
+        if dest_gcs and not gcs_object_is_directory(self.dest_gcs):
             self.log.info(
                 'Destination Google Cloud Storage path is not a valid '
                 '"directory", define a path that ends with a slash "/" or '
@@ -224,11 +224,3 @@ class S3ToGCSOperator(S3ListOperator):
             self.log.info('In sync, no files needed to be uploaded to Google Cloud' 'Storage')
 
         return files
-
-    # Following functionality may be better suited in
-    # airflow/providers/google/cloud/hooks/gcs.py
-    @staticmethod
-    def _gcs_object_is_directory(bucket):
-        _, blob = _parse_gcs_url(bucket)
-
-        return len(blob) == 0 or blob.endswith('/')
