@@ -26,12 +26,10 @@ from airflow.utils.dates import days_ago
 
 GCS_TO_GDRIVE_BUCKET = os.environ.get("GCS_TO_DRIVE_BUCKET", "example-object")
 
-default_args = {"start_date": days_ago(1)}
-
 with models.DAG(
     "example_gcs_to_gdrive",
-    default_args=default_args,
-    schedule_interval=None,
+    schedule_interval=None,  # Override to match your needs,
+    start_date=days_ago(1),
 ) as dag:
     # [START howto_operator_gcs_to_gdrive_copy_single_file]
     copy_single_file = GCSToGoogleDriveOperator(
